==> members-facade-2.2.9-20211220.024034-2-sources.jar: com/bizvane/members/facade/models/MemberLabelModel.java <==
package com.bizvane.members.facade.models;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.List;
import java.util.Map;

/**
 * 会员标签model
 * <p>
 * 内部使用
 *
 * @author houkai
 */

@Data
@NoArgsConstructor
@Table(name = "t_mbr_label_def")
public class MemberLabelModel extends BaseModel implements Serializable {

    private static final long serialVersionUID = 7593378701508448025L;

    @Id
    @ApiModelProperty(value = "标签id", name = "labelId", example = "标签id")
    private Long mbrLabelDefId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId", example = "企业id")
    private Long sysCompanyId;

    @ApiModelProperty(value = "所属品牌", name = "brandId", example = "所属品牌")
    private Long brandId;

    @ApiModelProperty(value = "标签编号", name = "labelCode", example = "标签编号")
    private String labelCode;

    @ApiModelProperty(value = "标签名称", name = "labelName", example = "标签名称")
    private String labelName;

    @ApiModelProperty(value = "标签类型", name = "labelType", example = "标签类型")
    private String labelType;

    @ApiModelProperty(value = "标签分组", name = "labelGroupId", example = "标签分组")
    private Long labelGroupId;

    @ApiModelProperty(value = "使用次数", name = "count", example = "使用次数")
    private Integer count;

    @ApiModelProperty(value = "标签名数组", name = "labelNameList", example = "标签名数组")
    private List<String> labelNameList;

    @ApiModelProperty(value = "是否允许导购贴/撕标签 0-不允许 1-允许", name = "openStaff")
    private Integer openStaff;

    /**
     * 是否加入回收站 1是 0否
     */
    private Boolean recycle;

    private List<Map> labelMap;

}

==> members-facade-2.3.8-20220726.060242-2-sources.jar: com/bizvane/members/facade/models/MemberLabelModel.java <==
package com.bizvane.members.facade.models;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.List;
import java.util.Map;

/**
 * 会员标签model
 * <p>
 * 内部使用
 *
 * @author houkai
 */

@Data
@NoArgsConstructor
@Table(name = "t_mbr_label_def")
public class MemberLabelModel extends BaseModel implements Serializable {

    private static final long serialVersionUID = 7593378701508448025L;

    @Id
    @ApiModelProperty(value = "标签id", name = "labelId", example = "标签id")
    private Long mbrLabelDefId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId", example = "企业id")
    private Long sysCompanyId;

    @ApiModelProperty(value = "所属品牌", name = "brandId", example = "所属品牌")
    private Long brandId;

    @ApiModelProperty(value = "标签编号", name = "labelCode", example = "标签编号")
    private String labelCode;

    @ApiModelProperty(value = "标签名称", name = "labelName", example = "标签名称")
    private String labelName;

    @ApiModelProperty(value = "标签类型", name = "labelType", example = "标签类型")
    private String labelType;

    @ApiModelProperty(value = "标签分组", name = "labelGroupId", example = "标签分组")
    private Long labelGroupId;

    @ApiModelProperty(value = "使用次数", name = "count", example = "使用次数")
    private Integer count;

    @ApiModelProperty(value = "标签名数组", name = "labelNameList", example = "标签名数组")
    private List<String> labelNameList;

    @ApiModelProperty(value = "是否允许导购贴/撕标签 0-不允许 1-允许", name = "openStaff")
    private Integer openStaff;

    /**
     * 企微标签分组 id
     */
    @ApiModelProperty(value = "企微标签id", name = "wxqyCorpTagId")
    private String wxqyCorpTagId;

    /**
     * 企微标签分组是否被删除 0否1是
     */
    @ApiModelProperty(value = "企微标签是否已删除 0否1是", name = "wxqyCorpTagDelete")
    private Integer wxqyCorpTagDelete;

    /**
     * 是否加入回收站 1是 0否
     */
    private Boolean recycle;

    private List<Map> labelMap;

}
